function makeInfo = rtwmakecfg()
% Configures the Real Time Workshop in a way that it is able to compile the
% blocks usrp_source and usrp_sink of the Universal Software Radio
% Peripheral (USRP) library.
%
% For help on this file, see "Real Time Workshop -> Writing S-Functions for
% Real-Time Workshop Code Generation -> Build Support for S-Functions ->
% Using the rtwmakecfg.m API"
%
% @version:		$Id: rtwmakecfg.m 213 2009-05-13 09:03:24Z nagel $
% @author:		Enno Klasing <klasing@int.uni-karlsruhe.de>
% @copyright:	Institut fr Nachrichtentechnik, http://www.int.uni-karlsruhe.de
% @license:		GNU General Public License, Version 3


% Include Paths / Source Paths...
binPath = pwd();
projectPath = fullfile(fileparts(pwd()), 'src');
makeInfo.includePath = {
    fullfile(projectPath, 'simulink-usrp', 'simulink-usrp')
    fullfile(projectPath, 'usrp', 'libusrp')
    fullfile(projectPath, 'usrp', 'libusrp', 'include')
    fullfile(projectPath, 'usrp', 'libusrp', 'include', 'usrp')
    fullfile(projectPath, 'includes')
};
makeInfo.sourcePath = {
    fullfile(projectPath, 'simulink-usrp', 'simulink-usrp')
    fullfile(projectPath, 'simulink-usrp', 'simulink-usrp-sink')
    fullfile(projectPath, 'simulink-usrp', 'simulink-usrp-source')
    fullfile(projectPath, 'usrp', 'libusrp')
    fullfile(projectPath, 'usrp', 'libusrp', 'include')
};
makeInfo.sources  = {};
makeInfo.linkLibsObjs = {};

% Compile additional libraries, they are not precompiled
makeInfo.precompile = 0;

% Library libusrp
makeInfo.library(1).Name = 'libusrp_rtw';
makeInfo.library(1).Location = binPath;
makeInfo.library(1).Modules = {
	'db_base'
	'db_basic'
	'db_boards'
	'db_dbs_rx'
	'db_dtt754'
	'db_dtt768'
	'db_flexrf'
	'db_flexrf_mimo'
	'db_tv_rx'
    'db_tv_rx_mimo'
	'db_util'
    'db_wbxng'
    'db_wbxng_adf4350'
    'db_wbxng_adf4350_regs'
	'db_xcvr2450'
	'fusb'
	'fusb_sysconfig_win32'
	'fusb_win32'
	'md5'
	'usrp_basic'
	'usrp_config'
	'usrp_dbid'
	'usrp_prims'
    'usrp_prims_libusb0'
	'usrp_standard'
	'libusb_dyn'
};

% Library simulink-usrp
makeInfo.library(2).Name = 'simulink_usrp_rtw';
makeInfo.library(2).Location = binPath;
makeInfo.library(2).Modules = {
    'MatlabArrayHelper'
    'SimulinkUsrpHelper'
    'UsrpHelper'
    'UsrpSimulinkSink'
    'UsrpSimulinkSource'
};

end
