function [ ] = usrpBuildFPGA()
%% Initialize parameter
model = get_param(gcs, 'Name');
targetlang = 'verilog';
generation_dir  = [model,'_hdlsrc'];
project_dir = [model,'_q2dir'];
orig_dir = regexprep([usrpGetFPGAPath,'\orig_verilog'],'\', '/');
incl_file = [orig_dir,'/include/common_config_gen.vh'];


%% Build the include file for the FPGA
fid = fopen(incl_file, 'wt');
fprintf(fid, '// This file is generated from usrpBuildFPGA \n');


%% Is there a RX path? What is its name?
block_rx = char(find_system(gcs,'RegExp', 'on','name','rx_chain'));
block_size = size(block_rx);
if block_size(1) == 0
    fprintf(fid, '// No RX path in the model \n');
    fprintf(fid, '`define RX_CAP_NCHAN 3''d0 \n');
    fprintf(fid, '`define RX_CAP_HB   0 \n');
    rx_flag = 0;
elseif block_size(1) == 1
    fprintf(fid, '// One RX path in the model \n');
    fprintf(fid, '`define RX_ON \n');
    fprintf(fid, '`define RX_CAP_NCHAN 3''d1 \n');
    fprintf(fid, '`define RX_CAP_HB   0 \n');
    rx_flag = 1;
else
    error('Only one RX path is supported in this version.');
end
block_rx = regexprep(block_rx,[model,'/'],'');

%% Is there a TX path? What is its name?
block_tx = char(find_system(gcs,'RegExp', 'on','name','tx_chain'));
block_size = size(block_tx);
if block_size(1) == 0
    fprintf(fid, '// No TX path in the model \n');
    fprintf(fid, '`define TX_CAP_NCHAN 3''d0 \n');
    fprintf(fid, '`define TX_CAP_HB   0 \n');
    tx_flag = 0;
elseif block_size(1) == 1
    fprintf(fid, '// One TX path in the model \n');
    fprintf(fid, '`define TX_ON \n');
    fprintf(fid, '`define TX_CAP_NCHAN 3''d1 \n');
    fprintf(fid, '`define TX_CAP_HB   0 \n');
    tx_flag = 1;
else
    error('Only one TX path is supported in this version.');
end
block_tx = regexprep(block_tx,[model,'/'],'');

fclose(fid);
clear('fid');

%% Get the name of the Bitfile Generator
block_bg = char(find_system(gcs,'RegExp', 'on','name','Bitfile_Generator'));
block_bg = regexprep(block_bg,[model,'/'],'');


%% Generate HDL for RX

if rx_flag == 1
    
    open_system([model,'/',block_rx]);
    makehdl(block_rx,...
        'targetlanguage',               'verilog',...
        'targetdirectory',              [generation_dir,'/',block_rx],...
        'EDAScriptGeneration',          'off',...
        'ClockEnableInputPort',         'enable',...
        'ForceClockEnable',             'off',...
        'ClockInputPort',               'clock',...
        'UseVerilogTimescale',          'off');
    close_system([model,'/',block_rx]);
    if replace_in_file([generation_dir,'/',block_rx,'/',block_rx,'.v'],'Timing_Controller',['Timing_Controller_',block_rx])
        replace_in_file([generation_dir,'/',block_rx,'/Timing_Controller.v'],'Timing_Controller',['Timing_Controller_',block_rx]);
        movefile([generation_dir,'/',block_rx,'/Timing_Controller.v'],[generation_dir,'/',block_rx,'/Timing_Controller_',block_rx,'.v']);
    end;
    
end;

%% Generate HDL for TX

if tx_flag
    open_system([model,'/',block_tx]);
    makehdl(block_tx,...
        'targetlanguage',               'verilog',...
        'targetdirectory',              [generation_dir,'/',block_tx],...
        'EDAScriptGeneration',          'off',...
        'ClockEnableInputPort',         'enable',...
        'ForceClockEnable',             'off',...
        'ClockInputPort',               'clock',...
        'UseVerilogTimescale',          'off');
    close_system([model,'/',block_tx]);
    if replace_in_file([generation_dir,'/',block_tx,'/',block_tx,'.v'],'Timing_Controller',['Timing_Controller_',block_tx])
        replace_in_file([generation_dir,'/',block_tx,'/Timing_Controller.v'],'Timing_Controller',['Timing_Controller_',block_tx]);
        movefile([generation_dir,'/',block_tx,'/Timing_Controller.v'],[generation_dir,'/',block_tx,'/Timing_Controller_',block_tx,'.v']);
    end;
    
end;


%% Generate TCL-Script with dummy block
makehdl([model,'/',block_bg],...
    'TargetLanguage', targetlang,...
    'TargetDirectory', generation_dir,...
    'EDAScriptGeneration',         'on',...
    'ClockEnableInputPort',        'enable',...
    'ForceClockEnable',            'off',...
    'ClockInputPort',              'clock',...
    'UseVerilogTimescale',         'off',...
    'HDLSynthFilePostfix',        '_quartus.tcl',...
    'HDLSynthInit',...
    ['load_package flow\n',...
    'set src_dir_rx "', [generation_dir,'/',block_rx], '"\n',...
    'set src_dir_tx "', [generation_dir,'/',block_tx], '"\n',...
    'set prj_dir "', project_dir, '"\n',...
    'set orig_dir "', orig_dir, '"\n',...
    'file mkdir $prj_dir\n',...
    'cd $prj_dir\n',...
    'set top_level usrp_std\n',...
    'project_new ',model,' -revision ',model,' -overwrite\n',...
    'set_global_assignment -name FAMILY "Cyclone"\n',...
    'set_global_assignment -name DEVICE EP1C12Q240C8\n',...
    'set_global_assignment -name TOP_LEVEL_ENTITY $top_level\n',...
    'set_global_assignment -name GENERATE_RBF_FILE ON\n',...
    'set_global_assignment -name CYCLONE_CONFIGURATION_SCHEME "PASSIVE SERIAL"\n',...
    'set_global_assignment -name RESERVE_ALL_UNUSED_PINS "AS INPUT TRI-STATED"\n',...
    'set_global_assignment -name OPTIMIZE_HOLD_TIMING OFF\n',...
    'set_global_assignment -name OPTIMIZE_TIMING "NORMAL COMPILATION"\n',...
    'set_global_assignment -name PHYSICAL_SYNTHESIS_COMBO_LOGIC OFF\n',...
    'set_global_assignment -name PHYSICAL_SYNTHESIS_REGISTER_DUPLICATION OFF\n',...
    'set_global_assignment -name PHYSICAL_SYNTHESIS_REGISTER_RETIMING OFF\n',...
    'set_global_assignment -name IO_PLACEMENT_OPTIMIZATION OFF\n',...
    'set_global_assignment -name PHYSICAL_SYNTHESIS_EFFORT NORMAL\n',...
    'set_global_assignment -name INC_PLC_MODE OFF\n',...
    'set_global_assignment -name ROUTING_BACK_ANNOTATION_MODE OFF\n',...
    'set_instance_assignment -name IO_STANDARD LVTTL -to usbdata[12]\n',...
    'set_global_assignment -name STRATIX_DEVICE_IO_STANDARD LVTTL\n',...
    'set_global_assignment -name ERROR_CHECK_FREQUENCY_DIVISOR 1\n',...
    'set_global_assignment -name RESERVE_PIN "AS INPUT TRI-STATED"\n',...
    'set_global_assignment -name INCLUDE_EXTERNAL_PIN_DELAYS_IN_FMAX_CALCULATIONS OFF"\n',...
    'set_global_assignment -name SAVE_DISK_SPACE OFF"\n',...
    'set_global_assignment -name DEVICE_FILTER_PACKAGE "ANY QFP"\n',...
    'set_global_assignment -name DEVICE_FILTER_PIN_COUNT 240\n',...
    'set_global_assignment -name EDA_DESIGN_ENTRY_SYNTHESIS_TOOL "<None>"\n',...
    'set_global_assignment -name CYCLONE_OPTIMIZATION_TECHNIQUE BALANCED\n',...
    'set_global_assignment -name AUTO_ENABLE_SMART_COMPILE ON\n',...
    'set_global_assignment -name MAX_SCC_SIZE 50\n',...
    'set_global_assignment -name EDA_SIMULATION_TOOL "<None>"\n',...
    'set_global_assignment -name EDA_TIMING_ANALYSIS_TOOL "<NONE>"\n',...
    'set_global_assignment -name EDA_BOARD_DESIGN_TOOL "<NONE>"\n',...
    'set_global_assignment -name EDA_FORMAL_VERIFICATION_TOOL "<NONE>"\n',...
    'set_global_assignment -name EDA_RESYNTHESIS_TOOL "<NONE>"\n',...
    'set_global_assignment -name USE_CONFIGURATION_DEVICE OFF"\n',...
    'set_global_assignment -name RESERVE_ALL_UNUSED_PINS_NO_OUTPUT_GND "AS INPUT TRI-STATED"\n',...
    'set_global_assignment -name AUTO_RESTART_CONFIGURATION OFF"\n',...
    'set_global_assignment -name START_TIME "0 ns"\n',...
    'set_global_assignment -name GLITCH_INTERVAL "1 ns"\n',...
    'set_global_assignment -name DRC_REPORT_TOP_FANOUT OFF"\n',...
    'set_global_assignment -name DRC_REPORT_FANOUT_EXCEEDING OFF"\n',...
    'set_global_assignment -name ASSG_CAT OFF"\n',...
    'set_global_assignment -name ASSG_RULE_MISSING_FMAX OFF"\n',...
    'set_global_assignment -name ASSG_RULE_MISSING_TIMING OFF"\n',...
    'set_global_assignment -name NONSYNCHSTRUCT_RULE_ASYN_RAM OFF"\n',...
    'set_global_assignment -name CLK_CAT OFF"\n',...
    'set_global_assignment -name CLK_RULE_COMB_CLOCK OFF"\n',...
    'set_global_assignment -name CLK_RULE_INV_CLOCK OFF"\n',...
    'set_global_assignment -name CLK_RULE_GATING_SCHEME OFF"\n',...
    'set_global_assignment -name CLK_RULE_INPINS_CLKNET OFF"\n',...
    'set_global_assignment -name CLK_RULE_CLKNET_CLKSPINES OFF"\n',...
    'set_global_assignment -name CLK_RULE_MIX_EDGES OFF"\n',...
    'set_global_assignment -name RESET_CAT OFF"\n',...
    'set_global_assignment -name RESET_RULE_INPINS_RESETNET OFF"\n',...
    'set_global_assignment -name RESET_RULE_UNSYNCH_EXRESET OFF"\n',...
    'set_global_assignment -name RESET_RULE_IMSYNCH_EXRESET OFF"\n',...
    'set_global_assignment -name RESET_RULE_COMB_ASYNCH_RESET OFF"\n',...
    'set_global_assignment -name RESET_RULE_UNSYNCH_ASYNCH_DOMAIN OFF"\n',...
    'set_global_assignment -name RESET_RULE_IMSYNCH_ASYNCH_DOMAIN OFF"\n',...
    'set_global_assignment -name TIMING_CAT OFF"\n',...
    'set_global_assignment -name TIMING_RULE_SHIFT_REG OFF"\n',...
    'set_global_assignment -name TIMING_RULE_COIN_CLKEDGE OFF"\n',...
    'set_global_assignment -name NONSYNCHSTRUCT_RULE_COMB_DRIVES_RAM_WE OFF"\n',...
    'set_global_assignment -name NONSYNCHSTRUCT_CAT OFF"\n',...
    'set_global_assignment -name NONSYNCHSTRUCT_RULE_COMBLOOP OFF"\n',...
    'set_global_assignment -name NONSYNCHSTRUCT_RULE_REG_LOOP OFF"\n',...
    'set_global_assignment -name NONSYNCHSTRUCT_RULE_DELAY_CHAIN OFF"\n',...
    'set_global_assignment -name NONSYNCHSTRUCT_RULE_RIPPLE_CLK OFF"\n',...
    'set_global_assignment -name NONSYNCHSTRUCT_RULE_ILLEGAL_PULSE_GEN OFF"\n',...
    'set_global_assignment -name NONSYNCHSTRUCT_RULE_MULTI_VIBRATOR OFF"\n',...
    'set_global_assignment -name NONSYNCHSTRUCT_RULE_SRLATCH OFF"\n',...
    'set_global_assignment -name NONSYNCHSTRUCT_RULE_LATCH_UNIDENTIFIED OFF"\n',...
    'set_global_assignment -name SIGNALRACE_CAT OFF"\n',...
    'set_global_assignment -name ACLK_CAT OFF"\n',...
    'set_global_assignment -name ACLK_RULE_NO_SZER_ACLK_DOMAIN OFF"\n',...
    'set_global_assignment -name ACLK_RULE_SZER_BTW_ACLK_DOMAIN OFF"\n',...
    'set_global_assignment -name ACLK_RULE_IMSZER_ADOMAIN OFF"\n',...
    'set_global_assignment -name HCPY_CAT OFF"\n',...
    'set_global_assignment -name HCPY_VREF_PINS OFF"\n',...
    'set_global_assignment -name HUB_ENTITY_NAME SLD_HUB\n',...
    'set_global_assignment -name HUB_INSTANCE_NAME SLD_HUB_INST\n',...
    'set_global_assignment -name ENABLE_SIGNALTAP OFF"\n',...
    'set_global_assignment -name LOGICLOCK_INCREMENTAL_COMPILE_ASSIGNMENT OFF"\n',...
    'set_global_assignment -name DUTY_CYCLE 50 -section_id SCLK\n',...
    'set_global_assignment -name FMAX_REQUIREMENT "1 MHz" -section_id SCLK\n',...
    'set_global_assignment -name INCLUDE_EXTERNAL_PIN_DELAYS_IN_FMAX_CALCULATIONS OFF -section_id SCLK\n',...
    'set_global_assignment -name DUTY_CYCLE 50 -section_id master_clk\n',...
    'set_global_assignment -name FMAX_REQUIREMENT "64 MHz" -section_id master_clk\n',...
    'set_global_assignment -name INCLUDE_EXTERNAL_PIN_DELAYS_IN_FMAX_CALCULATIONS OFF -section_id master_clk\n',...
    'set_global_assignment -name DUTY_CYCLE 50 -section_id usbclk\n',...
    'set_global_assignment -name FMAX_REQUIREMENT "48 MHz" -section_id usbclk\n',...
    'set_global_assignment -name INCLUDE_EXTERNAL_PIN_DELAYS_IN_FMAX_CALCULATIONS OFF -section_id usbclk\n',...
    'set_global_assignment -name PARTITION_NETLIST_TYPE SOURCE -section_id Top\n',...
    'set_global_assignment -name PARTITION_COLOR 16764057 -section_id Top\n',...
    'set_global_assignment -name LL_ROOT_REGION ON -section_id "Root Region"\n',...
    'set_global_assignment -name LL_MEMBER_STATE LOCKED -section_id "Root Region"\n',...
    'set_instance_assignment -name CLOCK_setTINGS SCLK -to SCLK\n',...
    'set_instance_assignment -name CLOCK_setTINGS usbclk -to usbclk\n',...
    'set_instance_assignment -name CLOCK_setTINGS master_clk -to master_clk\n',...
    'set_instance_assignment -name PARTITION_HIERARCHY root_partition -to | -section_id Top\n',...
    ],...
    'HDLSynthCmd',...
    ['foreach filename [glob ../$src_dir_rx/*.v] {set_global_assignment -name VERILOG_FILE $filename}\n',...
    'foreach filename [glob ../$src_dir_tx/*.v] {set_global_assignment -name VERILOG_FILE $filename}\n',...
    'set_global_assignment -name VERILOG_FILE $orig_dir/usrp_std.v\n',...
    'set_global_assignment -name VERILOG_FILE $orig_dir/sdr_lib/atr_delay.v\n',...
    'set_global_assignment -name VERILOG_FILE $orig_dir/sdr_lib/ddc.v\n',...
    'set_global_assignment -name VERILOG_FILE $orig_dir/sdr_lib/cic_dec_shifter.v\n',...
    'set_global_assignment -name VERILOG_FILE $orig_dir/sdr_lib/rssi.v\n',...
    'set_global_assignment -name VERILOG_FILE $orig_dir/sdr_lib/ram16.v\n',...
    'set_global_assignment -name VERILOG_FILE $orig_dir/sdr_lib/rx_dcoffset.v\n',...
    'set_global_assignment -name VERILOG_FILE $orig_dir/sdr_lib/adc_interface.v\n',...
    'set_global_assignment -name VERILOG_FILE $orig_dir/sdr_lib/io_pins.v\n',...
    'set_global_assignment -name VERILOG_FILE $orig_dir/sdr_lib/setting_reg.v\n',...
    'set_global_assignment -name VERILOG_FILE $orig_dir/sdr_lib/bidir_reg.v\n',...
    'set_global_assignment -name VERILOG_FILE $orig_dir/sdr_lib/cic_int_shifter.v\n',...
    'set_global_assignment -name VERILOG_FILE $orig_dir/sdr_lib/gen_sync.v\n',...
    'set_global_assignment -name VERILOG_FILE $orig_dir/sdr_lib/master_control.v\n',...
    'set_global_assignment -name VERILOG_FILE $orig_dir/sdr_lib/rx_buffer.v\n',...
    'set_global_assignment -name VERILOG_FILE $orig_dir/sdr_lib/tx_buffer.v\n',...
    'set_global_assignment -name VERILOG_FILE $orig_dir/sdr_lib/phase_acc.v\n',...
    'set_global_assignment -name VERILOG_FILE $orig_dir/sdr_lib/cic_interp.v\n',...
    'set_global_assignment -name VERILOG_FILE $orig_dir/sdr_lib/cic_decim.v\n',...
    'set_global_assignment -name VERILOG_FILE $orig_dir/sdr_lib/cordic_stage.v\n',...
    'set_global_assignment -name VERILOG_FILE $orig_dir/sdr_lib/cordic.v\n',...
    'set_global_assignment -name VERILOG_FILE $orig_dir/sdr_lib/clk_divider.v\n',...
    'set_global_assignment -name VERILOG_FILE $orig_dir/sdr_lib/serial_io.v\n',...
    'set_global_assignment -name VERILOG_FILE $orig_dir/sdr_lib/strobe_gen.v\n',...
    'set_global_assignment -name VERILOG_FILE $orig_dir/sdr_lib/sign_extend.v\n',...
    'set_global_assignment -name VERILOG_FILE $orig_dir/sdr_lib/hb/acc.v\n',...
    'set_global_assignment -name VERILOG_FILE $orig_dir/sdr_lib/hb/mult.v\n',...
    'set_global_assignment -name VERILOG_FILE $orig_dir/sdr_lib/hb/ram16_2sum.v\n',...
    'set_global_assignment -name VERILOG_FILE $orig_dir/sdr_lib/hb/coeff_rom.v\n',...
    'set_global_assignment -name VERILOG_FILE $orig_dir/sdr_lib/hb/halfband_decim.v\n',...
    'set_global_assignment -name VERILOG_FILE $orig_dir/sdr_lib/hb/mac.v\n',...
    'set_global_assignment -name VERILOG_FILE $orig_dir/megacells/fifo_4k_18.v\n',...
    'set_global_assignment -name VERILOG_FILE $orig_dir/megacells/fifo_4k.v\n',...
    'set_global_assignment -name VERILOG_FILE $orig_dir/megacells/clk_doubler.v\n',...
    'set_global_assignment -name VERILOG_FILE $orig_dir/megacells/fifo_2k.v\n',...
    'set_global_assignment -name VERILOG_FILE $orig_dir/megacells/bustri.v\n',...
    'set_location_assignment PIN_29 -to SCLK\n',...
    'set_location_assignment PIN_117 -to SDI\n',...
    'set_location_assignment PIN_28 -to usbclk\n',...
    'set_location_assignment PIN_107 -to usbctl[0]\n',...
    'set_location_assignment PIN_106 -to usbctl[1]\n',...
    'set_location_assignment PIN_105 -to usbctl[2]\n',...
    'set_location_assignment PIN_100 -to usbdata[0]\n',...
    'set_location_assignment PIN_84 -to usbdata[10]\n',...
    'set_location_assignment PIN_83 -to usbdata[11]\n',...
    'set_location_assignment PIN_82 -to usbdata[12]\n',...
    'set_location_assignment PIN_79 -to usbdata[13]\n',...
    'set_location_assignment PIN_78 -to usbdata[14]\n',...
    'set_location_assignment PIN_77 -to usbdata[15]\n',...
    'set_location_assignment PIN_99 -to usbdata[1]\n',...
    'set_location_assignment PIN_98 -to usbdata[2]\n',...
    'set_location_assignment PIN_95 -to usbdata[3]\n',...
    'set_location_assignment PIN_94 -to usbdata[4]\n',...
    'set_location_assignment PIN_93 -to usbdata[5]\n',...
    'set_location_assignment PIN_88 -to usbdata[6]\n',...
    'set_location_assignment PIN_87 -to usbdata[7]\n',...
    'set_location_assignment PIN_86 -to usbdata[8]\n',...
    'set_location_assignment PIN_85 -to usbdata[9]\n',...
    'set_location_assignment PIN_104 -to usbrdy[0]\n',...
    'set_location_assignment PIN_101 -to usbrdy[1]\n',...
    'set_location_assignment PIN_76 -to FX2_1\n',...
    'set_location_assignment PIN_75 -to FX2_2\n',...
    'set_location_assignment PIN_74 -to FX2_3\n',...
    'set_location_assignment PIN_116 -to io_rx_a[0]\n',...
    'set_location_assignment PIN_115 -to io_rx_a[1]\n',...
    'set_location_assignment PIN_114 -to io_rx_a[2]\n',...
    'set_location_assignment PIN_113 -to io_rx_a[3]\n',...
    'set_location_assignment PIN_108 -to io_rx_a[4]\n',...
    'set_location_assignment PIN_195 -to io_rx_a[5]\n',...
    'set_location_assignment PIN_196 -to io_rx_a[6]\n',...
    'set_location_assignment PIN_197 -to io_rx_a[7]\n',...
    'set_location_assignment PIN_200 -to io_rx_a[8]\n',...
    'set_location_assignment PIN_201 -to io_rx_a[9]\n',...
    'set_location_assignment PIN_202 -to io_rx_a[10]\n',...
    'set_location_assignment PIN_203 -to io_rx_a[11]\n',...
    'set_location_assignment PIN_206 -to io_rx_a[12]\n',...
    'set_location_assignment PIN_207 -to io_rx_a[13]\n',...
    'set_location_assignment PIN_208 -to io_rx_a[14]\n',...
    'set_location_assignment PIN_214 -to io_rx_b[0]\n',...
    'set_location_assignment PIN_215 -to io_rx_b[1]\n',...
    'set_location_assignment PIN_216 -to io_rx_b[2]\n',...
    'set_location_assignment PIN_217 -to io_rx_b[3]\n',...
    'set_location_assignment PIN_218 -to io_rx_b[4]\n',...
    'set_location_assignment PIN_219 -to io_rx_b[5]\n',...
    'set_location_assignment PIN_222 -to io_rx_b[6]\n',...
    'set_location_assignment PIN_223 -to io_rx_b[7]\n',...
    'set_location_assignment PIN_224 -to io_rx_b[8]\n',...
    'set_location_assignment PIN_225 -to io_rx_b[9]\n',...
    'set_location_assignment PIN_226 -to io_rx_b[10]\n',...
    'set_location_assignment PIN_227 -to io_rx_b[11]\n',...
    'set_location_assignment PIN_228 -to io_rx_b[12]\n',...
    'set_location_assignment PIN_233 -to io_rx_b[13]\n',...
    'set_location_assignment PIN_234 -to io_rx_b[14]\n',...
    'set_location_assignment PIN_175 -to io_tx_a[0]\n',...
    'set_location_assignment PIN_176 -to io_tx_a[1]\n',...
    'set_location_assignment PIN_177 -to io_tx_a[2]\n',...
    'set_location_assignment PIN_178 -to io_tx_a[3]\n',...
    'set_location_assignment PIN_179 -to io_tx_a[4]\n',...
    'set_location_assignment PIN_180 -to io_tx_a[5]\n',...
    'set_location_assignment PIN_181 -to io_tx_a[6]\n',...
    'set_location_assignment PIN_182 -to io_tx_a[7]\n',...
    'set_location_assignment PIN_183 -to io_tx_a[8]\n',...
    'set_location_assignment PIN_184 -to io_tx_a[9]\n',...
    'set_location_assignment PIN_185 -to io_tx_a[10]\n',...
    'set_location_assignment PIN_186 -to io_tx_a[11]\n',...
    'set_location_assignment PIN_187 -to io_tx_a[12]\n',...
    'set_location_assignment PIN_188 -to io_tx_a[13]\n',...
    'set_location_assignment PIN_193 -to io_tx_a[14]\n',...
    'set_location_assignment PIN_73 -to io_tx_b[0]\n',...
    'set_location_assignment PIN_68 -to io_tx_b[1]\n',...
    'set_location_assignment PIN_67 -to io_tx_b[2]\n',...
    'set_location_assignment PIN_66 -to io_tx_b[3]\n',...
    'set_location_assignment PIN_65 -to io_tx_b[4]\n',...
    'set_location_assignment PIN_64 -to io_tx_b[5]\n',...
    'set_location_assignment PIN_63 -to io_tx_b[6]\n',...
    'set_location_assignment PIN_62 -to io_tx_b[7]\n',...
    'set_location_assignment PIN_61 -to io_tx_b[8]\n',...
    'set_location_assignment PIN_60 -to io_tx_b[9]\n',...
    'set_location_assignment PIN_59 -to io_tx_b[10]\n',...
    'set_location_assignment PIN_58 -to io_tx_b[11]\n',...
    'set_location_assignment PIN_57 -to io_tx_b[12]\n',...
    'set_location_assignment PIN_56 -to io_tx_b[13]\n',...
    'set_location_assignment PIN_55 -to io_tx_b[14]\n',...
    'set_location_assignment PIN_152 -to master_clk\n',...
    'set_location_assignment PIN_144 -to rx_a_a[0]\n',...
    'set_location_assignment PIN_143 -to rx_a_a[1]\n',...
    'set_location_assignment PIN_141 -to rx_a_a[2]\n',...
    'set_location_assignment PIN_140 -to rx_a_a[3]\n',...
    'set_location_assignment PIN_139 -to rx_a_a[4]\n',...
    'set_location_assignment PIN_138 -to rx_a_a[5]\n',...
    'set_location_assignment PIN_137 -to rx_a_a[6]\n',...
    'set_location_assignment PIN_136 -to rx_a_a[7]\n',...
    'set_location_assignment PIN_135 -to rx_a_a[8]\n',...
    'set_location_assignment PIN_134 -to rx_a_a[9]\n',...
    'set_location_assignment PIN_133 -to rx_a_a[10]\n',...
    'set_location_assignment PIN_132 -to rx_a_a[11]\n',...
    'set_location_assignment PIN_23 -to rx_a_b[0]\n',...
    'set_location_assignment PIN_21 -to rx_a_b[1]\n',...
    'set_location_assignment PIN_20 -to rx_a_b[2]\n',...
    'set_location_assignment PIN_19 -to rx_a_b[3]\n',...
    'set_location_assignment PIN_18 -to rx_a_b[4]\n',...
    'set_location_assignment PIN_17 -to rx_a_b[5]\n',...
    'set_location_assignment PIN_16 -to rx_a_b[6]\n',...
    'set_location_assignment PIN_15 -to rx_a_b[7]\n',...
    'set_location_assignment PIN_14 -to rx_a_b[8]\n',...
    'set_location_assignment PIN_13 -to rx_a_b[9]\n',...
    'set_location_assignment PIN_12 -to rx_a_b[10]\n',...
    'set_location_assignment PIN_11 -to rx_a_b[11]\n',...
    'set_location_assignment PIN_131 -to rx_b_a[0]\n',...
    'set_location_assignment PIN_128 -to rx_b_a[1]\n',...
    'set_location_assignment PIN_127 -to rx_b_a[2]\n',...
    'set_location_assignment PIN_126 -to rx_b_a[3]\n',...
    'set_location_assignment PIN_125 -to rx_b_a[4]\n',...
    'set_location_assignment PIN_124 -to rx_b_a[5]\n',...
    'set_location_assignment PIN_123 -to rx_b_a[6]\n',...
    'set_location_assignment PIN_122 -to rx_b_a[7]\n',...
    'set_location_assignment PIN_121 -to rx_b_a[8]\n',...
    'set_location_assignment PIN_120 -to rx_b_a[9]\n',...
    'set_location_assignment PIN_119 -to rx_b_a[10]\n',...
    'set_location_assignment PIN_118 -to rx_b_a[11]\n',...
    'set_location_assignment PIN_8 -to rx_b_b[0]\n',...
    'set_location_assignment PIN_7 -to rx_b_b[1]\n',...
    'set_location_assignment PIN_6 -to rx_b_b[2]\n',...
    'set_location_assignment PIN_5 -to rx_b_b[3]\n',...
    'set_location_assignment PIN_4 -to rx_b_b[4]\n',...
    'set_location_assignment PIN_3 -to rx_b_b[5]\n',...
    'set_location_assignment PIN_2 -to rx_b_b[6]\n',...
    'set_location_assignment PIN_240 -to rx_b_b[7]\n',...
    'set_location_assignment PIN_239 -to rx_b_b[8]\n',...
    'set_location_assignment PIN_238 -to rx_b_b[9]\n',...
    'set_location_assignment PIN_237 -to rx_b_b[10]\n',...
    'set_location_assignment PIN_236 -to rx_b_b[11]\n',...
    'set_location_assignment PIN_156 -to SDO\n',...
    'set_location_assignment PIN_153 -to SEN_FPGA\n',...
    'set_location_assignment PIN_159 -to tx_a[0]\n',...
    'set_location_assignment PIN_160 -to tx_a[1]\n',...
    'set_location_assignment PIN_161 -to tx_a[2]\n',...
    'set_location_assignment PIN_162 -to tx_a[3]\n',...
    'set_location_assignment PIN_163 -to tx_a[4]\n',...
    'set_location_assignment PIN_164 -to tx_a[5]\n',...
    'set_location_assignment PIN_165 -to tx_a[6]\n',...
    'set_location_assignment PIN_166 -to tx_a[7]\n',...
    'set_location_assignment PIN_167 -to tx_a[8]\n',...
    'set_location_assignment PIN_168 -to tx_a[9]\n',...
    'set_location_assignment PIN_169 -to tx_a[10]\n',...
    'set_location_assignment PIN_170 -to tx_a[11]\n',...
    'set_location_assignment PIN_173 -to tx_a[12]\n',...
    'set_location_assignment PIN_174 -to tx_a[13]\n',...
    'set_location_assignment PIN_38 -to tx_b[0]\n',...
    'set_location_assignment PIN_39 -to tx_b[1]\n',...
    'set_location_assignment PIN_41 -to tx_b[2]\n',...
    'set_location_assignment PIN_42 -to tx_b[3]\n',...
    'set_location_assignment PIN_43 -to tx_b[4]\n',...
    'set_location_assignment PIN_44 -to tx_b[5]\n',...
    'set_location_assignment PIN_45 -to tx_b[6]\n',...
    'set_location_assignment PIN_46 -to tx_b[7]\n',...
    'set_location_assignment PIN_47 -to tx_b[8]\n',...
    'set_location_assignment PIN_48 -to tx_b[9]\n',...
    'set_location_assignment PIN_49 -to tx_b[10]\n',...
    'set_location_assignment PIN_50 -to tx_b[11]\n',...
    'set_location_assignment PIN_53 -to tx_b[12]\n',...
    'set_location_assignment PIN_54 -to tx_b[13]\n',...
    'set_location_assignment PIN_158 -to TXSYNC_A\n',...
    'set_location_assignment PIN_37 -to TXSYNC_B\n',...
    'set_location_assignment PIN_235 -to io_rx_b[15]\n',...
    'set_location_assignment PIN_24 -to io_tx_b[15]\n',...
    'set_location_assignment PIN_213 -to io_rx_a[15]\n',...
    'set_location_assignment PIN_194 -to io_tx_a[15]\n',...
    'set_location_assignment PIN_1 -to MYSTERY_SIGNAL\n',...
    ],...
    'HDLSynthTerm',...
    ['execute_flow -compile\n',...
    'project_close\n']);




%% Compile HDL
dos(['quartus_sh -t ',generation_dir,'/',block_bg,'_quartus.tcl'])

%% Copy bitfile to firmware
copyfile([project_dir,'/',model,'.rbf'],[usrpGetFirmwarePath,'/rev4/']);

%% Clear all variables
clear('block_bg');
clear('block_rx');
clear('block_tx');
clear('generation_dir');
clear('orig_dir');
clear('project_dir');
clear('model');
clear('targetlang');
clear('rx_flag');
clear('tx_flag');


end

