/**
 * usrp_helper MexFunction
 *
 * A MexFunction can be contained in a mex-File together with an S-Function by
 * calling it ProcessMexSfunctionCmdLineCall() and defining the makro
 * PROCESS_MEX_SFUNCTION_CMD_LINE_CALL. See also simulink.c at the end of
 * mexFunction().
 *
 * @version:	$Id: UsrpHelperMexFcn.h 220 2009-05-15 07:39:45Z nagel $
 * @author:		Enno Klasing <klasing@int.uni-karlsruhe.de>
 * @copyright:	Institut fr Nachrichtentechnik, http://www.int.uni-karlsruhe.de
 * @license:	GNU General Public License, Version 3
 */

#include <mex.h>


/**
 * Helper function for the Simulink-USRP-Interface
 *
 * Specify the desired action in prhs[0] as a Matlab string.
 * Specify additional parameters in prhs[1..] as needed.
 */
#define PROCESS_MEX_SFUNCTION_CMD_LINE_CALL
bool ProcessMexSfunctionCmdLineCall(int nlhs, mxArray *plhs[], int nrhs, const mxArray *prhs[]);


namespace UsrpHelperMexFcn
{
	/**
	 * Writes a string with the serial number of the Nth USRP Board on this computer, and a string
	 * with the name of all installed daughterboards, into the current Simulink Block.
	 *
	 * Used by usrp_helper.
	 *
	 * This function reads it's parameters from the current Simulink Block (which must be a
	 * usrp_* block, so only call this function from within a Simulink callback), and writes
	 * it's result into the same block's parameters.
	 */
	void BoardInfo(int nlhs, mxArray *plhs[], int nrhs, const mxArray *prhs[]);

	/**
	 * Writes a string with the serial number of the Nth USRP Board on this computer, and a string
	 * for each RX or TX subdevice, as well as the available gain ranges for each subdevice, into
	 * the current Simulink block.
	 *
	 * Used by usrp_source and usrp_sink.
	 *
	 * This function reads it's parameters from the current Simulink Block (which must be a
	 * usrp_* block, so only call this function from within a Simulink callback), and writes
	 * it's result into the same block's parameters.
	 */
	void BoardAndSubdeviceInfo(int nlhs, mxArray *plhs[], int nrhs, const mxArray *prhs[]);

	/**
	 * Writes the sampling rate and used bandwidth for a given decimation factor and samples width
	 * (8/16 Bit) into the current Simulink block.
	 *
	 * Used by usrp_source and usrp_sink.
	 *
	 * This function reads it's parameters from the current Simulink Block (which must be a
	 * usrp_* block, so only call this function from within a Simulink callback), and writes
	 * it's result into the same block's parameters.
	 */
	void SamplingRateAndBandwidth(int nlhs, mxArray *plhs[], int nrhs, const mxArray *prhs[]);

	/**
	 * Reads parameters from a usrp_helper block and returns them to Matlab.
	 *
	 * The usrp_helper block is determined by the usrp_number entered into the currently active
	 * usrp_source/usrp_sink block. Thus, this function can be used from the "S-Function
	 * parameters" dialog field of those blocks.
	 *
	 * @param	string		Name of the parameter (usb_block_size, usb_nblocks, firmware, bistream)
	 * @return	mxArray		Value of the param. Type of the array depends on param.
	 */
	void GetParam(int nlhs, mxArray *plhs[], int nrhs, const mxArray *prhs[]);

	/**
	 * Checks whether the currently active model is running
	 */
	bool SimulationIsRunning();
}
