/**
 * usrp_helper Simulink S-Function Callback Functions
 *
 * @version:	$Id: UsrpHelperSFcnCallbacks.cpp 220 2009-05-15 07:39:45Z nagel $
 * @author:		Enno Klasing <klasing@int.uni-karlsruhe.de>
 * @copyright:	Institut fr Nachrichtentechnik, http://www.int.uni-karlsruhe.de
 * @license:	GNU General Public License, Version 3
 */

#include "UsrpHelperSFcnCallbacks.h"


void
mdlInitializeSizes(SimStruct *S)
{
	// Redirect stdout and stderr into Matlab. To do this only once, we use stdout2matlab()
	// as one central place for doing this.
	mexCallMATLAB(0, NULL, 0, NULL, "stdout2matlab");

	// Check number of S-Function Parameters
	ssSetNumSFcnParams(S, 0);
	if (ssGetSFcnParamsCount(S) != 0) {
		// The Simulink engine displays an error message by itself.
		return;
	}

	// Input Ports
	if (!ssSetNumInputPorts(S, 0)) {
		// The Simulink engine displays an error message by itself.
		return;
	}

	// Output Ports
	if (!ssSetNumOutputPorts(S, 0)) {
		// The Simulink engine displays an error message by itself.
		return;
	}

	// Sample Times (Only one used, no sample time does not work, even if this block does nothing)
	ssSetNumSampleTimes(S, 1);

	// This block has no function during simulation, it may be eliminated by Simulink
	ssSetOptions(S, SS_OPTION_NONVOLATILE);
}

void
mdlInitializeSampleTimes(SimStruct *S)
{
	// Inherited sample time. An inherited Sample Time will make this block use the fastest sample
	// time in the model, thus making sure that no new sample time is introduced into the model.
	// Since this block has the option SS_OPTION_NONVOLATILE set, it's sample time does not matter
	// as mdlOutputs will never be called anyway.
	ssSetSampleTime(S, 0, -1);
	ssSetOffsetTime(S, 0, 0.0);
}

void
mdlOutputs(SimStruct *S, int_T tid)
{
	// Output a warning about BlockReduction being swiched off _once_ per block
	if (ssGetUserData(S) == 0) {
		ssSetUserData(S, reinterpret_cast <void *> (1));
		mexWarnMsgTxt(
			"usrp_helper block is executing. "
			"You can disable this diagnostic by enabling the 'Block Reduction' option on the "
			"Optimization pane of the Configuration Parameters dialog box."
		);
	}
}

void
mdlTerminate(SimStruct *S)
{
}
