/**
 * Helper functions to handle parameter extraction from mxArrays
 *
 * @version:	$Id: MatlabArrayHelper.h 220 2009-05-15 07:39:45Z nagel $
 * @author:		Enno Klasing <klasing@int.uni-karlsruhe.de>
 * @copyright:	Institut fr Nachrichtentechnik, http://www.int.uni-karlsruhe.de
 * @license:	GNU General Public License, Version 3
 */

#include <simstruc.h>
#include <string>
#include <limits>


namespace MatlabArrayHelper
{
	/**
	 * Extracts a parameter from an array.
	 *
	 * @param	mxArray		Array from which the parameter shall be extracted.
	 * @param	string		Name of this parameter.
	 */
	double getDoubleFromArray(
		const mxArray *inArray, const std::string paramName = "", bool strict = false,
		double rangeMin = -DBL_MAX, double rangeMax = DBL_MAX
	);
	inline float getFloatFromArray(
		const mxArray *inArray, const std::string paramName = "", bool strict = false,
		float rangeMin = -FLT_MAX, float rangeMax = FLT_MAX
	) {
		return static_cast <float> (
			getDoubleFromArray(inArray, paramName, strict, rangeMin, rangeMax)
		);
	};
	int getIntFromArray(
		const mxArray *inArray, const std::string paramName = "", bool strict = false,
		int rangeMin = INT_MIN, int rangeMax = INT_MAX
	);
	bool getBoolFromArray(
		const mxArray *inArray, const std::string paramName = "", bool strict = false
	);
#ifdef MATLAB_MEX_FILE
	std::wstring getWStringFromArray(
		const mxArray *inArray, const std::string paramName = ""
	);
#endif
	std::string getStringFromArray(
		const mxArray *inArray, const std::string paramName = ""
	);
};
