/**
 * Helper functions to find USRP blocks in a Simulink System
 *
 * @version:	$Id: MatlabUsrpHelper.h 220 2009-05-15 07:39:45Z nagel $
 * @author:		Enno Klasing <klasing@int.uni-karlsruhe.de>
 * @copyright:	Institut fr Nachrichtentechnik, http://www.int.uni-karlsruhe.de
 * @license:	GNU General Public License, Version 3
 */

#include <mat.h>
#include <string>
#include <vector>


namespace MatlabUsrpHelper
{
	/**
	 * Returns a vector of paths to all usrp_helper blocks in the specified system
	 *
	 * @param	string	Name of the System/Subsystem, which shall be searched
	 * @return	vector	Names of all usrp_helper blocks
	 */
	std::vector <std::string> findUsrpHelperBlocks(const mxArray* system);

	/**
	 * Returns the paths to a usrp_helper block which controls parameters for the Nth
	 * USRP on this computer.
	 *
	 * @param	string	Name of the System/Subsystem, which shall be searched.
	 * @param	int		The block must be for the Nth USRP on this computer.
	 * @return	vector	Name of the usrp_helper block (empty if none is found).
	 * @throws			Throws if multiple blocks for the same USRP are found
	 */
	std::string findUsrpHelperBlock(const mxArray* system, const mxArray* usrpNumber);

	/**
	 * Fetches a parameter from a usrp_helper block.
	 *
	 * Returns NULL if no helper block was found. You need to destroy this mxArray when you are done
	 * using it.
	 *
	 * @param	string	Name of the root model.
	 * @param	mxArray	Array with the parameter usrp_number of the current block.
	 * @param	string	Name of the parameter which is to be fetched from the helper block.
	 */
	mxArray *fetchParamFromHelperBlock(
		const mxArray* system, const mxArray *usrpNumberArray, const std::string paramName
	);
};
