/**
 * Helper file for fetching information from a Simulink SimStruct
 *
 * @version:	$Id: SimulinkUsrpHelper.h 220 2009-05-15 07:39:45Z nagel $
 * @author:		Enno Klasing <klasing@int.uni-karlsruhe.de>
 * @copyright:	Institut fr Nachrichtentechnik, http://www.int.uni-karlsruhe.de
 * @license:	GNU General Public License, Version 3
 */

#include <string>
#include <simstruc.h>
#include <vector>


namespace SimulinkUsrpHelper
{
	/**
	 * Struct with information about one single subdevice, fetched from the params of an S-Function.
	 */
	struct subdevInfo {
		bool enabled;
		CSignal_T complexOutput;
		std::string dataType;
		subdevInfo();
	};

	/**
	 * Counts the number of enabled subdevices
	 *
	 * This information is extracted from the parameters of an S-Function.
	 *
	 * @param	SimStruc
	 * @param	int		Maximum number of subdevs (and therefore also parameters).
	 * @param	int		Number of the first dataType parameter of the S-Function.
	 * @param	int		Distance between the dataType parameters of two subdevices.
	 * @param	vector	If this vector has the same size as MAX_SUBDEV_COUNT, the extracted values
	 *					are written into the corresponding place of the vector.
	 * @param	int		Number of output ports (which might be more than enabled subdevs (complex/real)).
	 * @return	int		The number of enabled subdevices.
	 */
	int countEnabledSubdevices(
		const SimStruct *S,
		const int MAX_SUBDEV_COUNT, const int PARAM_DATATYPE_INDEX, const int PARAM_DISTANCE,
		std::vector <subdevInfo> &subdeviceInfo = std::vector <subdevInfo>(), int *outputCount = NULL
	);

	/**
	 * Converts a data-type string into the number of a Simulink builtin datatype
	 */
	bool dataTypeString2BuiltinDataType(const subdevInfo subdev, BuiltInDTypeId &dataType);

	/**
	 * Sets the environment Variable USRP_PATH, which is then used by find_file in usrp_prims.cc
	 */
	bool setPathEnvironmentVar();
};
