/**
 * Helper file to open a named pipe, which will be forwarded to mexPrintf.
 *
 * This is done because otherwise the output of fputs() or fprintf(stderr/stdout)
 * won't be shown in Matlab.
 *
 * @version:	$Id: log2namedPipe.h 220 2009-05-15 07:39:45Z nagel $
 * @author:		Enno Klasing <klasing@int.uni-karlsruhe.de>
 * @copyright:	Institut fr Nachrichtentechnik, http://www.int.uni-karlsruhe.de
 * @license:	GNU General Public License, Version 3
 */


/**
 * Redirects stdout and stderr into two named pipes, which will call mexPrintf() for all data coming
 * it's way.
 *
 * The current process ID is used to generate the pipe name, so that each Matlab instace has it's own
 * pipes.
 *
 * In order to deallocate all resources allocated by this function, you must call
 * deleteStdoutAndStderrRedrection() when your library gets unloaded. You can do this either by
 * calling this function with the parameter "registerMexAtExit" set to true, by calling the
 * function from your own exit function, or by passing it as an argument to mexAtExit:
 * mexAtExit(deleteStdoutAndStderrRedrection);
 *
 * If compiled with _DEBUG, status messages about the created pipes will be printed into Matlab.
 *
 * @param	bool		True [default] to make this function call
 *						mexAtExit(deleteStdoutAndStderrRedirection). If you set this to false,
 *						it is your responsibility to call deleteStdoutAndStderrRedirection()
 *						from your own exit function.
 * @param	bool		True to print out status messages.
 * @return	bool		True on success.
 */
bool redirectStdoutAndStderr(bool registerMexAtExit = true, bool verbose = true);

/**
 * Closes stdout and stderr, thus effectively breaking the pipes and ending the pipe listener threads.
 */
void deleteStdoutAndStderrRedirection();
