/**
 * Redirects stdout and stderr into two named pipes, which will call mexPrintf() for all data coming
 * it's way. This makes it possible to see output written into stdout/stderr in Matlab under Windows.
 * 
 * @version:	$Id: stdout2matlab.cpp 220 2009-05-15 07:39:45Z nagel $
 * @author:		Enno Klasing <klasing@int.uni-karlsruhe.de>
 * @copyright:	Institut fr Nachrichtentechnik, http://www.int.uni-karlsruhe.de
 * @license:	GNU General Public License, Version 3
 */

#include <string>
#include "log2namedPipe.h"
#include "mex.h"

using namespace std;


/**
 * Redirects stdout and stderr into two named pipes, which will call mexPrintf() for all data coming
 * it's way. This makes it possible to see output written into stdout/stderr in Matlab under Windows.
 *
 * @param	mxDouble	1.0 to display status messages, 0.0 to suppress status messages. Errors will
 *						still be printed. Optional.
 * @return	mxLogical	True if everything worked out fine. Optional.
 */
void
mexFunction(int nlhs, mxArray *plhs[], int nrhs, const mxArray *prhs[])
{
	bool result = false;
#ifdef _DEBUG
	bool verbose = true;
#else
	bool verbose = false;
#endif

	// Check number of parameters
	if (nrhs < 0 || nrhs > 1 || nlhs < 0 || nrhs > 1) {
		mexErrMsgTxt("Wrong number of arguments.\n");
	}

	// Read param 1 (verbose), if given
	if (nrhs > 0) {
		if (mxIsDouble(prhs[0])) {
			verbose = mxGetPr(prhs[0])[0] != 0.0;
		} else if (mxIsLogicalScalar(prhs[0])) {
			verbose = mxIsLogicalScalarTrue(prhs[0]);
		} else {
			mexErrMsgTxt("Param 1 must be of type 'double' or 'logical'.\n");
		}
	}

	// Redirect stdout and stderr into Matlab
	result = redirectStdoutAndStderr(true, verbose);
	if (!result) {
		mexPrintf("stdout and stderr could NOT be redirected into Matlab. You may not see every output of included 3rd party code.\n");
	}

	// Return result
	if (nlhs > 0) {
		plhs[0] = mxCreateLogicalScalar(result);
	}
}
